# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/image.proto\x12\tis.vision\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16is_msgs/validate.proto\"1\n\x05Image\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\t\n\x07\x63ontent\"h\n\x0bImageFormat\x12\'\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x17.is.vision.ImageFormats\x12\x30\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\")\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"3\n\x0c\x42oundingPoly\x12#\n\x08vertices\x18\x01 \x03(\x0b\x32\x11.is.vision.Vertex\"+\n\nResolution\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\r\"3\n\nColorSpace\x12%\n\x05value\x18\x01 \x01(\x0e\x32\x16.is.vision.ColorSpaces\"\xb7\x01\n\rImageSettings\x12)\n\nresolution\x18\x01 \x01(\x0b\x32\x15.is.vision.Resolution\x12&\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\x16.is.vision.ImageFormat\x12*\n\x0b\x63olor_space\x18\x03 \x01(\x0b\x32\x15.is.vision.ColorSpace\x12\'\n\x06region\x18\x04 \x01(\x0b\x32\x17.is.vision.BoundingPoly\"d\n\x0fPointAnnotation\x12\n\n\x02id\x18\x01 \x01(\x03\x12 \n\x05score\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00\x12#\n\x08position\x18\x03 \x01(\x0b\x32\x11.is.vision.Vertex\"\xa7\x01\n\x10ObjectAnnotation\x12\r\n\x05label\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\x12 \n\x05score\x18\x03 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00\x12\'\n\x06region\x18\x04 \x01(\x0b\x32\x17.is.vision.BoundingPoly\x12-\n\tkeypoints\x18\x05 \x03(\x0b\x32\x1a.is.vision.PointAnnotation\"~\n\x11ObjectAnnotations\x12,\n\x07objects\x18\x01 \x03(\x0b\x32\x1b.is.vision.ObjectAnnotation\x12)\n\nresolution\x18\x02 \x01(\x0b\x32\x15.is.vision.Resolution\x12\x10\n\x08\x66rame_id\x18\x03 \x01(\x03*+\n\x0cImageFormats\x12\x07\n\x03PNG\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x08\n\x04WebP\x10\x02*4\n\x0b\x43olorSpaces\x12\x07\n\x03RGB\x10\x00\x12\x08\n\x04GRAY\x10\x01\x12\t\n\x05YCbCr\x10\x02\x12\x07\n\x03HSV\x10\x03*\xd5\x02\n\x0eHumanKeypoints\x12\x1a\n\x16UNKNOWN_HUMAN_KEYPOINT\x10\x00\x12\x08\n\x04HEAD\x10\x01\x12\x08\n\x04NOSE\x10\x02\x12\x08\n\x04NECK\x10\x03\x12\x12\n\x0eRIGHT_SHOULDER\x10\x04\x12\x0f\n\x0bRIGHT_ELBOW\x10\x05\x12\x0f\n\x0bRIGHT_WRIST\x10\x06\x12\x11\n\rLEFT_SHOULDER\x10\x07\x12\x0e\n\nLEFT_ELBOW\x10\x08\x12\x0e\n\nLEFT_WRIST\x10\t\x12\r\n\tRIGHT_HIP\x10\n\x12\x0e\n\nRIGHT_KNEE\x10\x0b\x12\x0f\n\x0bRIGHT_ANKLE\x10\x0c\x12\x0c\n\x08LEFT_HIP\x10\r\x12\r\n\tLEFT_KNEE\x10\x0e\x12\x0e\n\nLEFT_ANKLE\x10\x0f\x12\r\n\tRIGHT_EYE\x10\x10\x12\x0c\n\x08LEFT_EYE\x10\x11\x12\r\n\tRIGHT_EAR\x10\x12\x12\x0c\n\x08LEFT_EAR\x10\x13\x12\t\n\x05\x43HEST\x10\x14*6\n\x0cObjectLabels\x12\x12\n\x0eUNKNOWN_OBJECT\x10\x00\x12\x12\n\x0eHUMAN_SKELETON\x10\x01\x42\x11\n\rcom.is.visionP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.image_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.visionP\001'
  _POINTANNOTATION.fields_by_name['score']._options = None
  _POINTANNOTATION.fields_by_name['score']._serialized_options = b'\272\351\300\003\014\n\n\035\000\000\200?-\000\000\000\000'
  _OBJECTANNOTATION.fields_by_name['score']._options = None
  _OBJECTANNOTATION.fields_by_name['score']._serialized_options = b'\272\351\300\003\014\n\n\035\000\000\200?-\000\000\000\000'
  _IMAGEFORMATS._serialized_start=1027
  _IMAGEFORMATS._serialized_end=1070
  _COLORSPACES._serialized_start=1072
  _COLORSPACES._serialized_end=1124
  _HUMANKEYPOINTS._serialized_start=1127
  _HUMANKEYPOINTS._serialized_end=1468
  _OBJECTLABELS._serialized_start=1470
  _OBJECTLABELS._serialized_end=1524
  _IMAGE._serialized_start=90
  _IMAGE._serialized_end=139
  _IMAGEFORMAT._serialized_start=141
  _IMAGEFORMAT._serialized_end=245
  _VERTEX._serialized_start=247
  _VERTEX._serialized_end=288
  _BOUNDINGPOLY._serialized_start=290
  _BOUNDINGPOLY._serialized_end=341
  _RESOLUTION._serialized_start=343
  _RESOLUTION._serialized_end=386
  _COLORSPACE._serialized_start=388
  _COLORSPACE._serialized_end=439
  _IMAGESETTINGS._serialized_start=442
  _IMAGESETTINGS._serialized_end=625
  _POINTANNOTATION._serialized_start=627
  _POINTANNOTATION._serialized_end=727
  _OBJECTANNOTATION._serialized_start=730
  _OBJECTANNOTATION._serialized_end=897
  _OBJECTANNOTATIONS._serialized_start=899
  _OBJECTANNOTATIONS._serialized_end=1025
# @@protoc_insertion_point(module_scope)
