# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/tests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/tests.proto\x12\x08is.tests\x1a\x16is_msgs/validate.proto\"s\n\x03\x46oo\x12$\n\x05myint\x18\x01 \x01(\x05\x42\x15\xba\xe9\xc0\x03\x10\x1a\x0e\x18\xd0\x0f(\xce\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\"\n\x07myfloat\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x15\x9a\x99\x99>%\xcd\xcc\xcc=\x12\"\n\x08mydouble\x18\x03 \x01(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t\x19\xb4\xc8v\xbe\x9f\xaa@@\"B\n\x03\x42\x61r\x12\x1c\n\x05myfoo\x18\x01 \x01(\x0b\x32\r.is.tests.Foo\x12\x1d\n\x07myfloat\x18\x02 \x01(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05%\x00\x00\x80\xbf\"\x87\x02\n\x07Repeats\x12\x1b\n\x04\x66oos\x18\x01 \x03(\x0b\x32\r.is.tests.Foo\x12\'\n\x04\x66oo2\x18\x02 \x01(\x0b\x32\r.is.tests.FooB\n\xba\xe9\xc0\x03\x05\x8a\x01\x02\x10\x01\x12\"\n\x06int32s\x18\x03 \x03(\x05\x42\x12\xba\xe9\xc0\x03\r\x1a\x0b\x10\xf6\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\x07uint32s\x18\x04 \x03(\rB\t\xba\xe9\xc0\x03\x04*\x02 \n\x12\x1c\n\x06\x66loats\x18\x05 \x03(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05\x1d\x00\x00 \xc1\x12!\n\x07\x64oubles\x18\x06 \x03(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t)\x00\x00\x00\x00\x00\x00$\xc0\x12\x19\n\x06int64s\x18\x07 \x03(\x03\x42\t\xba\xe9\xc0\x03\x04\"\x02\x10\n\x12\x1a\n\x07uint64s\x18\x08 \x03(\x04\x42\t\xba\xe9\xc0\x03\x04\x32\x02 db\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.tests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOO.fields_by_name['myint']._options = None
  _FOO.fields_by_name['myint']._serialized_options = b'\272\351\300\003\020\032\016\030\320\017(\316\377\377\377\377\377\377\377\377\001'
  _FOO.fields_by_name['myfloat']._options = None
  _FOO.fields_by_name['myfloat']._serialized_options = b'\272\351\300\003\014\n\n\025\232\231\231>%\315\314\314='
  _FOO.fields_by_name['mydouble']._options = None
  _FOO.fields_by_name['mydouble']._serialized_options = b'\272\351\300\003\013\022\t\031\264\310v\276\237\252@@'
  _BAR.fields_by_name['myfloat']._options = None
  _BAR.fields_by_name['myfloat']._serialized_options = b'\272\351\300\003\007\n\005%\000\000\200\277'
  _REPEATS.fields_by_name['foo2']._options = None
  _REPEATS.fields_by_name['foo2']._serialized_options = b'\272\351\300\003\005\212\001\002\020\001'
  _REPEATS.fields_by_name['int32s']._options = None
  _REPEATS.fields_by_name['int32s']._serialized_options = b'\272\351\300\003\r\032\013\020\366\377\377\377\377\377\377\377\377\001'
  _REPEATS.fields_by_name['uint32s']._options = None
  _REPEATS.fields_by_name['uint32s']._serialized_options = b'\272\351\300\003\004*\002 \n'
  _REPEATS.fields_by_name['floats']._options = None
  _REPEATS.fields_by_name['floats']._serialized_options = b'\272\351\300\003\007\n\005\035\000\000 \301'
  _REPEATS.fields_by_name['doubles']._options = None
  _REPEATS.fields_by_name['doubles']._serialized_options = b'\272\351\300\003\013\022\t)\000\000\000\000\000\000$\300'
  _REPEATS.fields_by_name['int64s']._options = None
  _REPEATS.fields_by_name['int64s']._serialized_options = b'\272\351\300\003\004\"\002\020\n'
  _REPEATS.fields_by_name['uint64s']._options = None
  _REPEATS.fields_by_name['uint64s']._serialized_options = b'\272\351\300\003\0042\002 d'
  _FOO._serialized_start=57
  _FOO._serialized_end=172
  _BAR._serialized_start=174
  _BAR._serialized_end=240
  _REPEATS._serialized_start=243
  _REPEATS._serialized_end=506
# @@protoc_insertion_point(module_scope)
