# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/power.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/power.proto\x12\tis.common\x1a\x1egoogle/protobuf/duration.proto\"\xbc\x03\n\tPowerInfo\x12\x0f\n\x07voltage\x18\x01 \x01(\x02\x12\x18\n\x10terminal_voltage\x18\x02 \x01(\x02\x12\x14\n\x0c\x63\x65ll_voltage\x18\x03 \x03(\x02\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x02\x12\x10\n\x08\x63\x61pacity\x18\x05 \x01(\x02\x12.\n\x04type\x18\x06 \x01(\x0e\x32 .is.common.PowerInfo.BatteryType\x12\x32\n\x06status\x18\x07 \x01(\x0e\x32\".is.common.PowerInfo.BatteryStatus\x12)\n\x06uptime\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x61utonomy\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\"3\n\x0b\x42\x61tteryType\x12\x06\n\x02PB\x10\x00\x12\x08\n\x04NICD\x10\x01\x12\x08\n\x04NIMH\x10\x02\x12\x08\n\x04LIPO\x10\x03\"[\n\rBatteryStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x43HARGING\x10\x01\x12\x0f\n\x0b\x44ISCHARGING\x10\x02\x12\x0b\n\x07\x43HARGED\x10\x03\x12\x11\n\rNOT_CONNECTED\x10\x04\x42\x11\n\rcom.is.commonP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.power_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.commonP\001'
  _POWERINFO._serialized_start=67
  _POWERINFO._serialized_end=511
  _POWERINFO_BATTERYTYPE._serialized_start=367
  _POWERINFO_BATTERYTYPE._serialized_end=418
  _POWERINFO_BATTERYSTATUS._serialized_start=420
  _POWERINFO_BATTERYSTATUS._serialized_end=511
# @@protoc_insertion_point(module_scope)
