# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/camera.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import common_pb2 as is__msgs_dot_common__pb2
from is_msgs import image_pb2 as is__msgs_dot_image__pb2
from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14is_msgs/camera.proto\x12\tis.vision\x1a\x14is_msgs/common.proto\x1a\x13is_msgs/image.proto\x1a\x16is_msgs/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"T\n\rCameraSetting\x12\x11\n\tautomatic\x18\x01 \x01(\x08\x12 \n\x05ratio\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00\x12\x0e\n\x06option\x18\x03 \x01(\t\"\xf5\x04\n\x0e\x43\x61meraSettings\x12,\n\nbrightness\x18\x01 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12*\n\x08\x65xposure\x18\x02 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\'\n\x05\x66ocus\x18\x03 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04gain\x18\x04 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\'\n\x05gamma\x18\x05 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12%\n\x03hue\x18\x06 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04iris\x18\x07 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12,\n\nsaturation\x18\x08 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12+\n\tsharpness\x18\t \x01(\x0b\x32\x18.is.vision.CameraSetting\x12)\n\x07shutter\x18\n \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\x32\n\x10white_balance_bu\x18\x0b \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\x32\n\x10white_balance_rv\x18\x0c \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04zoom\x18\r \x01(\x0b\x32\x18.is.vision.CameraSetting\x12*\n\x08\x63ontrast\x18\x0e \x01(\x0b\x32\x18.is.vision.CameraSetting\"V\n\nPTZControl\x12%\n\x08\x61\x62solute\x18\x01 \x01(\x0b\x32\x13.is.common.Position\x12!\n\x04step\x18\x02 \x01(\x0b\x32\x13.is.common.Position\"\xa5\x02\n\x0c\x43\x61meraConfig\x12-\n\x08sampling\x18\x01 \x01(\x0b\x32\x1b.is.common.SamplingSettings\x12\'\n\x05image\x18\x02 \x01(\x0b\x32\x18.is.vision.ImageSettings\x12)\n\x06\x63\x61mera\x18\x03 \x01(\x0b\x32\x19.is.vision.CameraSettings\x12\x36\n\x11stream_channel_id\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12/\n\nchannel_id\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12)\n\nptzcontrol\x18\x06 \x01(\x0b\x32\x15.is.vision.PTZControl\"\x8c\x02\n\x11\x43\x61meraCalibration\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x31\n\rcalibrated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x03 \x01(\x01\x12)\n\nresolution\x18\x04 \x01(\x0b\x32\x15.is.vision.Resolution\x12$\n\tintrinsic\x18\x05 \x01(\x0b\x32\x11.is.common.Tensor\x12%\n\ndistortion\x18\x06 \x01(\x0b\x32\x11.is.common.Tensor\x12\x31\n\textrinsic\x18\x07 \x03(\x0b\x32\x1e.is.vision.FrameTransformation\"~\n\x13\x46rameTransformation\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\x12\x1d\n\x02tf\x18\x03 \x01(\x0b\x32\x11.is.common.Tensor\x12.\n\nexpiration\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x14\x46rameTransformations\x12+\n\x03tfs\x18\x01 \x03(\x0b\x32\x1e.is.vision.FrameTransformation\"\"\n\x06IdPair\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\":\n\x18GetTransformationRequest\x12\x1e\n\x03ids\x18\x01 \x03(\x0b\x32\x11.is.vision.IdPair\"Q\n\x16GetTransformationReply\x12\x37\n\x0ftransformations\x18\x01 \x03(\x0b\x32\x1e.is.vision.FrameTransformation\"\x1a\n\x18\x41\x64\x64TransformationRequest\"\x18\n\x16\x41\x64\x64TransformationReply\"$\n\x15GetCalibrationRequest\x12\x0b\n\x03ids\x18\x01 \x03(\x03\"I\n\x13GetCalibrationReply\x12\x32\n\x0c\x63\x61librations\x18\x01 \x03(\x0b\x32\x1c.is.vision.CameraCalibration*\x9d\x01\n\x12\x43\x61meraConfigFields\x12\x07\n\x03\x41LL\x10\x00\x12\x15\n\x11SAMPLING_SETTINGS\x10\x01\x12\x12\n\x0eIMAGE_SETTINGS\x10\x02\x12\x13\n\x0f\x43\x41MERA_SETTINGS\x10\x03\x12\x15\n\x11STREAM_CHANNEL_ID\x10\x04\x12\x0e\n\nCHANNEL_ID\x10\x05\x12\x17\n\x13PTZCONTROL_SETTINGS\x10\x06\x42\x11\n\rcom.is.visionP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.camera_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.visionP\001'
  _CAMERASETTING.fields_by_name['ratio']._options = None
  _CAMERASETTING.fields_by_name['ratio']._serialized_options = b'\272\351\300\003\014\n\n\035\000\000\200?-\000\000\000\000'
  _CAMERACONFIGFIELDS._serialized_start=2084
  _CAMERACONFIGFIELDS._serialized_end=2241
  _CAMERASETTING._serialized_start=167
  _CAMERASETTING._serialized_end=251
  _CAMERASETTINGS._serialized_start=254
  _CAMERASETTINGS._serialized_end=883
  _PTZCONTROL._serialized_start=885
  _PTZCONTROL._serialized_end=971
  _CAMERACONFIG._serialized_start=974
  _CAMERACONFIG._serialized_end=1267
  _CAMERACALIBRATION._serialized_start=1270
  _CAMERACALIBRATION._serialized_end=1538
  _FRAMETRANSFORMATION._serialized_start=1540
  _FRAMETRANSFORMATION._serialized_end=1666
  _FRAMETRANSFORMATIONS._serialized_start=1668
  _FRAMETRANSFORMATIONS._serialized_end=1735
  _IDPAIR._serialized_start=1737
  _IDPAIR._serialized_end=1771
  _GETTRANSFORMATIONREQUEST._serialized_start=1773
  _GETTRANSFORMATIONREQUEST._serialized_end=1831
  _GETTRANSFORMATIONREPLY._serialized_start=1833
  _GETTRANSFORMATIONREPLY._serialized_end=1914
  _ADDTRANSFORMATIONREQUEST._serialized_start=1916
  _ADDTRANSFORMATIONREQUEST._serialized_end=1942
  _ADDTRANSFORMATIONREPLY._serialized_start=1944
  _ADDTRANSFORMATIONREPLY._serialized_end=1968
  _GETCALIBRATIONREQUEST._serialized_start=1970
  _GETCALIBRATIONREQUEST._serialized_end=2006
  _GETCALIBRATIONREPLY._serialized_start=2008
  _GETCALIBRATIONREPLY._serialized_end=2081
# @@protoc_insertion_point(module_scope)
