# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14is_msgs/common.proto\x12\tis.common\x1a\x1egoogle/protobuf/wrappers.proto\"n\n\x10SamplingSettings\x12.\n\tfrequency\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12*\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"N\n\x0bSyncRequest\x12\x10\n\x08\x65ntities\x18\x01 \x03(\t\x12-\n\x08sampling\x18\x02 \x01(\x0b\x32\x1b.is.common.SamplingSettings\"\x1f\n\rFieldSelector\x12\x0e\n\x06\x66ields\x18\x01 \x03(\r\"Z\n\x05Shape\x12(\n\x04\x64ims\x18\x01 \x03(\x0b\x32\x1a.is.common.Shape.Dimension\x1a\'\n\tDimension\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9d\x01\n\x06Tensor\x12\x1f\n\x05shape\x18\x01 \x01(\x0b\x32\x10.is.common.Shape\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.is.common.DataType\x12\x12\n\x06\x66loats\x18\x03 \x03(\x02\x42\x02\x10\x01\x12\x13\n\x07\x64oubles\x18\x04 \x03(\x01\x42\x02\x10\x01\x12\x12\n\x06ints32\x18\x05 \x03(\x05\x42\x02\x10\x01\x12\x12\n\x06ints64\x18\x06 \x03(\x03\x42\x02\x10\x01\"+\n\x08Position\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"7\n\x0bOrientation\x12\x0b\n\x03yaw\x18\x01 \x01(\x02\x12\r\n\x05pitch\x18\x02 \x01(\x02\x12\x0c\n\x04roll\x18\x03 \x01(\x02\"Z\n\x04Pose\x12%\n\x08position\x18\x01 \x01(\x0b\x32\x13.is.common.Position\x12+\n\x0borientation\x18\x02 \x01(\x0b\x32\x16.is.common.Orientation\"(\n\x05Speed\x12\x0e\n\x06linear\x18\x01 \x01(\x02\x12\x0f\n\x07\x61ngular\x18\x02 \x01(\x02\"!\n\x0c\x43onsumerInfo\x12\x11\n\tconsumers\x18\x02 \x03(\t\"\x85\x01\n\x0c\x43onsumerList\x12/\n\x04info\x18\x01 \x03(\x0b\x32!.is.common.ConsumerList.InfoEntry\x1a\x44\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.is.common.ConsumerInfo:\x02\x38\x01\"?\n\x06Phrase\x12\x0f\n\x07\x63ontent\x18\x01 \x03(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\x10\n\x08language\x18\x03 \x01(\t*]\n\x08\x44\x61taType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0e\n\nFLOAT_TYPE\x10\x01\x12\x0f\n\x0b\x44OUBLE_TYPE\x10\x02\x12\x0e\n\nINT32_TYPE\x10\x03\x12\x0e\n\nINT64_TYPE\x10\x04\x42\x11\n\rcom.is.commonP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.commonP\001'
  _TENSOR.fields_by_name['floats']._options = None
  _TENSOR.fields_by_name['floats']._serialized_options = b'\020\001'
  _TENSOR.fields_by_name['doubles']._options = None
  _TENSOR.fields_by_name['doubles']._serialized_options = b'\020\001'
  _TENSOR.fields_by_name['ints32']._options = None
  _TENSOR.fields_by_name['ints32']._serialized_options = b'\020\001'
  _TENSOR.fields_by_name['ints64']._options = None
  _TENSOR.fields_by_name['ints64']._serialized_options = b'\020\001'
  _CONSUMERLIST_INFOENTRY._options = None
  _CONSUMERLIST_INFOENTRY._serialized_options = b'8\001'
  _DATATYPE._serialized_start=1016
  _DATATYPE._serialized_end=1109
  _SAMPLINGSETTINGS._serialized_start=67
  _SAMPLINGSETTINGS._serialized_end=177
  _SYNCREQUEST._serialized_start=179
  _SYNCREQUEST._serialized_end=257
  _FIELDSELECTOR._serialized_start=259
  _FIELDSELECTOR._serialized_end=290
  _SHAPE._serialized_start=292
  _SHAPE._serialized_end=382
  _SHAPE_DIMENSION._serialized_start=343
  _SHAPE_DIMENSION._serialized_end=382
  _TENSOR._serialized_start=385
  _TENSOR._serialized_end=542
  _POSITION._serialized_start=544
  _POSITION._serialized_end=587
  _ORIENTATION._serialized_start=589
  _ORIENTATION._serialized_end=644
  _POSE._serialized_start=646
  _POSE._serialized_end=736
  _SPEED._serialized_start=738
  _SPEED._serialized_end=778
  _CONSUMERINFO._serialized_start=780
  _CONSUMERINFO._serialized_end=813
  _CONSUMERLIST._serialized_start=816
  _CONSUMERLIST._serialized_end=949
  _CONSUMERLIST_INFOENTRY._serialized_start=881
  _CONSUMERLIST_INFOENTRY._serialized_end=949
  _PHRASE._serialized_start=951
  _PHRASE._serialized_end=1014
# @@protoc_insertion_point(module_scope)
