# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/robot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import common_pb2 as is__msgs_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/robot.proto\x12\x08is.robot\x1a\x14is_msgs/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\tRangeScan\x12\x0e\n\x06\x61ngles\x18\x01 \x03(\x02\x12\x0e\n\x06ranges\x18\x02 \x03(\x02\".\n\x0bRobotConfig\x12\x1f\n\x05speed\x18\x01 \x01(\x0b\x32\x10.is.common.Speed\"\xb1\x01\n\rBasicMoveTask\x12&\n\tpositions\x18\x01 \x03(\x0b\x32\x13.is.common.Position\x12 \n\x06speeds\x18\x02 \x03(\x0b\x32\x10.is.common.Speed\x12\x31\n\x11\x66inal_orientation\x18\x03 \x01(\x0b\x32\x16.is.common.Orientation\x12\x15\n\rallowed_error\x18\x04 \x01(\x02\x12\x0c\n\x04rate\x18\x05 \x01(\x02\"Z\n\x10RobotTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x32\n\x0f\x62\x61sic_move_task\x18\x02 \x01(\x0b\x32\x17.is.robot.BasicMoveTaskH\x00\x42\x06\n\x04Task\"\x1c\n\x0eRobotTaskReply\x12\n\n\x02id\x18\x01 \x01(\x04\"\xa4\x02\n\x17RobotControllerProgress\x12\n\n\x02id\x18\t \x01(\x04\x12\'\n\rcurrent_speed\x18\x01 \x01(\x0b\x32\x10.is.common.Speed\x12%\n\x0c\x63urrent_pose\x18\x02 \x01(\x0b\x32\x0f.is.common.Pose\x12%\n\x0c\x64\x65sired_pose\x18\x03 \x01(\x0b\x32\x0f.is.common.Pose\x12\r\n\x05\x65rror\x18\x04 \x01(\x02\x12\x12\n\ncompletion\x18\x05 \x01(\x02\x12\x0f\n\x07sources\x18\x06 \x03(\t\x12)\n\x05\x62\x65gin\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x83\x01\n\x0bPathRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12)\n\x10\x64\x65stination_pose\x18\x02 \x01(\x0b\x32\x0f.is.common.Pose\x12\x18\n\x10robot_gateway_id\x18\x03 \x01(\x04\x12\x0c\n\x04rate\x18\x04 \x01(\x02\x12\x15\n\rallowed_error\x18\x05 \x01(\x02\x42\x10\n\x0c\x63om.is.robotP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.robot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.is.robotP\001'
  _RANGESCAN._serialized_start=88
  _RANGESCAN._serialized_end=131
  _ROBOTCONFIG._serialized_start=133
  _ROBOTCONFIG._serialized_end=179
  _BASICMOVETASK._serialized_start=182
  _BASICMOVETASK._serialized_end=359
  _ROBOTTASKREQUEST._serialized_start=361
  _ROBOTTASKREQUEST._serialized_end=451
  _ROBOTTASKREPLY._serialized_start=453
  _ROBOTTASKREPLY._serialized_end=481
  _ROBOTCONTROLLERPROGRESS._serialized_start=484
  _ROBOTCONTROLLERPROGRESS._serialized_end=776
  _PATHREQUEST._serialized_start=779
  _PATHREQUEST._serialized_end=910
# @@protoc_insertion_point(module_scope)
