# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/validate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16is_msgs/validate.proto\x12\x0bis.validate\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdc\x07\n\nFieldRules\x12(\n\x05\x66loat\x18\x01 \x01(\x0b\x32\x17.is.validate.FloatRulesH\x00\x12*\n\x06\x64ouble\x18\x02 \x01(\x0b\x32\x18.is.validate.DoubleRulesH\x00\x12(\n\x05int32\x18\x03 \x01(\x0b\x32\x17.is.validate.Int32RulesH\x00\x12(\n\x05int64\x18\x04 \x01(\x0b\x32\x17.is.validate.Int64RulesH\x00\x12*\n\x06uint32\x18\x05 \x01(\x0b\x32\x18.is.validate.UInt32RulesH\x00\x12*\n\x06uint64\x18\x06 \x01(\x0b\x32\x18.is.validate.UInt64RulesH\x00\x12*\n\x06sint32\x18\x07 \x01(\x0b\x32\x18.is.validate.SInt32RulesH\x00\x12*\n\x06sint64\x18\x08 \x01(\x0b\x32\x18.is.validate.SInt64RulesH\x00\x12,\n\x07\x66ixed32\x18\t \x01(\x0b\x32\x19.is.validate.Fixed32RulesH\x00\x12,\n\x07\x66ixed64\x18\n \x01(\x0b\x32\x19.is.validate.Fixed64RulesH\x00\x12.\n\x08sfixed32\x18\x0b \x01(\x0b\x32\x1a.is.validate.SFixed32RulesH\x00\x12.\n\x08sfixed64\x18\x0c \x01(\x0b\x32\x1a.is.validate.SFixed64RulesH\x00\x12&\n\x04\x62ool\x18\r \x01(\x0b\x32\x16.is.validate.BoolRulesH\x00\x12*\n\x06string\x18\x0e \x01(\x0b\x32\x18.is.validate.StringRulesH\x00\x12(\n\x05\x62ytes\x18\x0f \x01(\x0b\x32\x17.is.validate.BytesRulesH\x00\x12&\n\x04\x65num\x18\x10 \x01(\x0b\x32\x16.is.validate.EnumRulesH\x00\x12,\n\x07message\x18\x11 \x01(\x0b\x32\x19.is.validate.MessageRulesH\x00\x12.\n\x08repeated\x18\x12 \x01(\x0b\x32\x1a.is.validate.RepeatedRulesH\x00\x12$\n\x03map\x18\x13 \x01(\x0b\x32\x15.is.validate.MapRulesH\x00\x12$\n\x03\x61ny\x18\x14 \x01(\x0b\x32\x15.is.validate.AnyRulesH\x00\x12.\n\x08\x64uration\x18\x15 \x01(\x0b\x32\x1a.is.validate.DurationRulesH\x00\x12\x30\n\ttimestamp\x18\x16 \x01(\x0b\x32\x1b.is.validate.TimestampRulesH\x00\x42\x06\n\x04type\"i\n\nFloatRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x02\x12\n\n\x02lt\x18\x02 \x01(\x02\x12\x0b\n\x03lte\x18\x03 \x01(\x02\x12\n\n\x02gt\x18\x04 \x01(\x02\x12\x0b\n\x03gte\x18\x05 \x01(\x02\x12\n\n\x02in\x18\x06 \x03(\x02\x12\x0e\n\x06not_in\x18\x07 \x03(\x02\"j\n\x0b\x44oubleRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x01\x12\n\n\x02lt\x18\x02 \x01(\x01\x12\x0b\n\x03lte\x18\x03 \x01(\x01\x12\n\n\x02gt\x18\x04 \x01(\x01\x12\x0b\n\x03gte\x18\x05 \x01(\x01\x12\n\n\x02in\x18\x06 \x03(\x01\x12\x0e\n\x06not_in\x18\x07 \x03(\x01\"i\n\nInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x05\x12\n\n\x02lt\x18\x02 \x01(\x05\x12\x0b\n\x03lte\x18\x03 \x01(\x05\x12\n\n\x02gt\x18\x04 \x01(\x05\x12\x0b\n\x03gte\x18\x05 \x01(\x05\x12\n\n\x02in\x18\x06 \x03(\x05\x12\x0e\n\x06not_in\x18\x07 \x03(\x05\"i\n\nInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x03\x12\n\n\x02lt\x18\x02 \x01(\x03\x12\x0b\n\x03lte\x18\x03 \x01(\x03\x12\n\n\x02gt\x18\x04 \x01(\x03\x12\x0b\n\x03gte\x18\x05 \x01(\x03\x12\n\n\x02in\x18\x06 \x03(\x03\x12\x0e\n\x06not_in\x18\x07 \x03(\x03\"j\n\x0bUInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\r\x12\n\n\x02lt\x18\x02 \x01(\r\x12\x0b\n\x03lte\x18\x03 \x01(\r\x12\n\n\x02gt\x18\x04 \x01(\r\x12\x0b\n\x03gte\x18\x05 \x01(\r\x12\n\n\x02in\x18\x06 \x03(\r\x12\x0e\n\x06not_in\x18\x07 \x03(\r\"j\n\x0bUInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x04\x12\n\n\x02lt\x18\x02 \x01(\x04\x12\x0b\n\x03lte\x18\x03 \x01(\x04\x12\n\n\x02gt\x18\x04 \x01(\x04\x12\x0b\n\x03gte\x18\x05 \x01(\x04\x12\n\n\x02in\x18\x06 \x03(\x04\x12\x0e\n\x06not_in\x18\x07 \x03(\x04\"j\n\x0bSInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x11\x12\n\n\x02lt\x18\x02 \x01(\x11\x12\x0b\n\x03lte\x18\x03 \x01(\x11\x12\n\n\x02gt\x18\x04 \x01(\x11\x12\x0b\n\x03gte\x18\x05 \x01(\x11\x12\n\n\x02in\x18\x06 \x03(\x11\x12\x0e\n\x06not_in\x18\x07 \x03(\x11\"j\n\x0bSInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x12\x12\n\n\x02lt\x18\x02 \x01(\x12\x12\x0b\n\x03lte\x18\x03 \x01(\x12\x12\n\n\x02gt\x18\x04 \x01(\x12\x12\x0b\n\x03gte\x18\x05 \x01(\x12\x12\n\n\x02in\x18\x06 \x03(\x12\x12\x0e\n\x06not_in\x18\x07 \x03(\x12\"k\n\x0c\x46ixed32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x07\x12\n\n\x02lt\x18\x02 \x01(\x07\x12\x0b\n\x03lte\x18\x03 \x01(\x07\x12\n\n\x02gt\x18\x04 \x01(\x07\x12\x0b\n\x03gte\x18\x05 \x01(\x07\x12\n\n\x02in\x18\x06 \x03(\x07\x12\x0e\n\x06not_in\x18\x07 \x03(\x07\"k\n\x0c\x46ixed64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x06\x12\n\n\x02lt\x18\x02 \x01(\x06\x12\x0b\n\x03lte\x18\x03 \x01(\x06\x12\n\n\x02gt\x18\x04 \x01(\x06\x12\x0b\n\x03gte\x18\x05 \x01(\x06\x12\n\n\x02in\x18\x06 \x03(\x06\x12\x0e\n\x06not_in\x18\x07 \x03(\x06\"l\n\rSFixed32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x0f\x12\n\n\x02lt\x18\x02 \x01(\x0f\x12\x0b\n\x03lte\x18\x03 \x01(\x0f\x12\n\n\x02gt\x18\x04 \x01(\x0f\x12\x0b\n\x03gte\x18\x05 \x01(\x0f\x12\n\n\x02in\x18\x06 \x03(\x0f\x12\x0e\n\x06not_in\x18\x07 \x03(\x0f\"l\n\rSFixed64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x10\x12\n\n\x02lt\x18\x02 \x01(\x10\x12\x0b\n\x03lte\x18\x03 \x01(\x10\x12\n\n\x02gt\x18\x04 \x01(\x10\x12\x0b\n\x03gte\x18\x05 \x01(\x10\x12\n\n\x02in\x18\x06 \x03(\x10\x12\x0e\n\x06not_in\x18\x07 \x03(\x10\"\x1a\n\tBoolRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x08\"\xc6\x02\n\x0bStringRules\x12\r\n\x05\x63onst\x18\x01 \x01(\t\x12\x0f\n\x07min_len\x18\x02 \x01(\x04\x12\x0f\n\x07max_len\x18\x03 \x01(\x04\x12\x11\n\tmin_bytes\x18\x04 \x01(\x04\x12\x11\n\tmax_bytes\x18\x05 \x01(\x04\x12\x0f\n\x07pattern\x18\x06 \x01(\t\x12\x0e\n\x06prefix\x18\x07 \x01(\t\x12\x0e\n\x06suffix\x18\x08 \x01(\t\x12\x10\n\x08\x63ontains\x18\t \x01(\t\x12\n\n\x02in\x18\n \x03(\t\x12\x0e\n\x06not_in\x18\x0b \x03(\t\x12\x0f\n\x05\x65mail\x18\x0c \x01(\x08H\x00\x12\x12\n\x08hostname\x18\r \x01(\x08H\x00\x12\x0c\n\x02ip\x18\x0e \x01(\x08H\x00\x12\x0e\n\x04ipv4\x18\x0f \x01(\x08H\x00\x12\x0e\n\x04ipv6\x18\x10 \x01(\x08H\x00\x12\r\n\x03uri\x18\x11 \x01(\x08H\x00\x12\x11\n\x07uri_ref\x18\x12 \x01(\x08H\x00\x42\x0c\n\nwell_known\"\xd8\x01\n\nBytesRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x0c\x12\x0f\n\x07min_len\x18\x02 \x01(\x04\x12\x0f\n\x07max_len\x18\x03 \x01(\x04\x12\x0f\n\x07pattern\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\x0c\x12\x0e\n\x06suffix\x18\x06 \x01(\x0c\x12\x10\n\x08\x63ontains\x18\x07 \x01(\x0c\x12\n\n\x02in\x18\x08 \x03(\x0c\x12\x0e\n\x06not_in\x18\t \x03(\x0c\x12\x0c\n\x02ip\x18\n \x01(\x08H\x00\x12\x0e\n\x04ipv4\x18\x0b \x01(\x08H\x00\x12\x0e\n\x04ipv6\x18\x0c \x01(\x08H\x00\x42\x0c\n\nwell_known\"L\n\tEnumRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x05\x12\x14\n\x0c\x64\x65\x66ined_only\x18\x02 \x01(\x08\x12\n\n\x02in\x18\x03 \x03(\x05\x12\x0e\n\x06not_in\x18\x04 \x03(\x05\".\n\x0cMessageRules\x12\x0c\n\x04skip\x18\x01 \x01(\x08\x12\x10\n\x08required\x18\x02 \x01(\x08\"m\n\rRepeatedRules\x12\x11\n\tmin_items\x18\x01 \x01(\x04\x12\x11\n\tmax_items\x18\x02 \x01(\x04\x12\x0e\n\x06unique\x18\x03 \x01(\x08\x12&\n\x05items\x18\x04 \x01(\x0b\x32\x17.is.validate.FieldRules\"\x93\x01\n\x08MapRules\x12\x11\n\tmin_pairs\x18\x01 \x01(\x04\x12\x11\n\tmax_pairs\x18\x02 \x01(\x04\x12\x11\n\tno_sparse\x18\x03 \x01(\x08\x12%\n\x04keys\x18\x04 \x01(\x0b\x32\x17.is.validate.FieldRules\x12\'\n\x06values\x18\x05 \x01(\x0b\x32\x17.is.validate.FieldRules\"8\n\x08\x41nyRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\n\n\x02in\x18\x02 \x03(\t\x12\x0e\n\x06not_in\x18\x03 \x03(\t\"\xbb\x02\n\rDurationRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12(\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02lt\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03lte\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02gt\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03gte\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02in\x18\x07 \x03(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06not_in\x18\x08 \x03(\x0b\x32\x19.google.protobuf.Duration\"\xba\x02\n\x0eTimestampRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12)\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02lt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03lte\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02gt\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03gte\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06lt_now\x18\x07 \x01(\x08\x12\x0e\n\x06gt_now\x18\x08 \x01(\x08\x12)\n\x06within\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration:3\n\x08\x64isabled\x12\x1f.google.protobuf.MessageOptions\x18\x97\x8d\x38 \x01(\x08:1\n\x08required\x12\x1d.google.protobuf.OneofOptions\x18\x97\x8d\x38 \x01(\x08:G\n\x05rules\x12\x1d.google.protobuf.FieldOptions\x18\x97\x8d\x38 \x01(\x0b\x32\x17.is.validate.FieldRules')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.validate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(disabled)
  google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(required)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(rules)

  DESCRIPTOR._options = None
  _FIELDRULES._serialized_start=139
  _FIELDRULES._serialized_end=1127
  _FLOATRULES._serialized_start=1129
  _FLOATRULES._serialized_end=1234
  _DOUBLERULES._serialized_start=1236
  _DOUBLERULES._serialized_end=1342
  _INT32RULES._serialized_start=1344
  _INT32RULES._serialized_end=1449
  _INT64RULES._serialized_start=1451
  _INT64RULES._serialized_end=1556
  _UINT32RULES._serialized_start=1558
  _UINT32RULES._serialized_end=1664
  _UINT64RULES._serialized_start=1666
  _UINT64RULES._serialized_end=1772
  _SINT32RULES._serialized_start=1774
  _SINT32RULES._serialized_end=1880
  _SINT64RULES._serialized_start=1882
  _SINT64RULES._serialized_end=1988
  _FIXED32RULES._serialized_start=1990
  _FIXED32RULES._serialized_end=2097
  _FIXED64RULES._serialized_start=2099
  _FIXED64RULES._serialized_end=2206
  _SFIXED32RULES._serialized_start=2208
  _SFIXED32RULES._serialized_end=2316
  _SFIXED64RULES._serialized_start=2318
  _SFIXED64RULES._serialized_end=2426
  _BOOLRULES._serialized_start=2428
  _BOOLRULES._serialized_end=2454
  _STRINGRULES._serialized_start=2457
  _STRINGRULES._serialized_end=2783
  _BYTESRULES._serialized_start=2786
  _BYTESRULES._serialized_end=3002
  _ENUMRULES._serialized_start=3004
  _ENUMRULES._serialized_end=3080
  _MESSAGERULES._serialized_start=3082
  _MESSAGERULES._serialized_end=3128
  _REPEATEDRULES._serialized_start=3130
  _REPEATEDRULES._serialized_end=3239
  _MAPRULES._serialized_start=3242
  _MAPRULES._serialized_end=3389
  _ANYRULES._serialized_start=3391
  _ANYRULES._serialized_end=3447
  _DURATIONRULES._serialized_start=3450
  _DURATIONRULES._serialized_end=3765
  _TIMESTAMPRULES._serialized_start=3768
  _TIMESTAMPRULES._serialized_end=4082
# @@protoc_insertion_point(module_scope)
